' This file is part of Network Switcher.

' Network Switcher is free software: you can redistribute it and/or modify
' it under the terms of the GNU General Public License as published by
' the Free Software Foundation, either version 3 of the License, or
' (at your option) any later version.

' Network Switcher is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
' GNU General Public License for more details.

' You should have received a copy of the GNU General Public License
' along with Network Switcher. If not, see <http://www.gnu.org/licenses/>.
'
' Copyright 2007, Ricardo Amaral
    
Imports NetworkSwitcher.Interfaces
Imports Microsoft.Win32
Imports System.Windows.Forms

Public Class IEProxy

#Region " Plugin Initialization "

    Implements IPlugin

    Private objHost As IHost

    Public Sub Initialize(ByVal Host As IHost) Implements IPlugin.Initialize
        objHost = Host
    End Sub

#End Region

#Region " Plugin Properties (About Information) "

    Public ReadOnly Property PluginName() As String Implements IPlugin.PluginName
        Get
            Return "Internet Explorer Proxy"
        End Get
    End Property

    Public ReadOnly Property PluginVersion() As String Implements IPlugin.PluginVersion
        Get
            Return "1.0"
        End Get
    End Property

    Public ReadOnly Property PluginAuthor() As String Implements IPlugin.PluginAuthor
        Get
            Return "Ricardo Amaral"
        End Get
    End Property

    Public ReadOnly Property PluginDescription() As String Implements IPlugin.PluginDescription
        Get
            Return "This plugin will enable or disable the use of a proxy server in Internet Explorer according to Network Switcher proxy settings."
        End Get
    End Property

#End Region

    Public Function GetMethods() As PluginDelegate() Implements IPlugin.GetMethods
        Return New PluginDelegate() { _
            AddressOf EnableProxy, _
            AddressOf DisableProxy _
        }
    End Function

    Public Sub EnableProxy()
        If objHost.DirectConnection = False Then
            Dim regKey As RegistryKey

            regKey = Registry.CurrentUser.OpenSubKey("Software\Microsoft\Windows\CurrentVersion\Internet Settings", True)

            regKey.SetValue("ProxyEnable", True, RegistryValueKind.DWord)
            regKey.SetValue("ProxyServer", objHost.ProxyAddress.ToString + ":" + objHost.ProxyPort.ToString, RegistryValueKind.String)

            If objHost.BypassLocal Then
                regKey.SetValue("ProxyOverride", "<local>", RegistryValueKind.String)
            Else
                regKey.DeleteValue("ProxyOverride", False)
            End If

            regKey.Close()
        Else
            MessageBox.Show("Network Switcher is currently not configured to use a proxy server. " + ControlChars.CrLf + _
                            "Please open Network Switcher settings dialog and configure the proxy server.", "Missing proxy settings", MessageBoxButtons.OK, MessageBoxIcon.Exclamation)
        End If
    End Sub

    Public Sub DisableProxy()
        Dim regKey As RegistryKey

        regKey = Registry.CurrentUser.OpenSubKey("Software\Microsoft\Windows\CurrentVersion\Internet Settings", True)

        regKey.SetValue("ProxyEnable", False, RegistryValueKind.DWord)

        regKey.Close()
    End Sub

End Class
