' This file is part of Network Switcher.

' Network Switcher is free software: you can redistribute it and/or modify
' it under the terms of the GNU General Public License as published by
' the Free Software Foundation, either version 3 of the License, or
' (at your option) any later version.

' Network Switcher is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
' GNU General Public License for more details.

' You should have received a copy of the GNU General Public License
' along with Network Switcher. If not, see <http://www.gnu.org/licenses/>.

Imports NetworkSwitcher.Interfaces

Public Class FormProfilesManager

#Region " Class Declarations "

    Dim exitFromTray As Boolean
    Dim frmSettings As New FormSettings, frmAbout As New FormAbout

#End Region

#Region " Controls Events "

    ' Start creating a new profile
    Private Sub btnAdd_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnAdd.Click
        ' Important settings not set?
        If Settings.NicFolder Is Nothing Or Settings.EnableVerb Is Nothing Or Settings.DisableVerb Is Nothing Then
            MessageBox.Show("No profile can be added before configuring some important settings." + ControlChars.CrLf + "Settings dialog will now be displayed...", "Invalid Settings!", MessageBoxButtons.OK, MessageBoxIcon.Information)

            ' Focus the form if it's already visible or show the dialog
            If frmSettings.Visible Then
                frmSettings.Focus()
            Else
                frmSettings.ShowDialog()
            End If
        Else
            Dim frmNewProfile As New FormNewProfile, frmNewProfileName As New FormProfileName

            frmNewProfileName.ShowDialog()

            ' Continue creating new profile?
            If newProfile Then
                ' Show new profile dialog
                frmNewProfile.ShowDialog()
            End If
        End If
    End Sub

    ' Remove the current selected profile
    Private Sub btnRemove_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnRemove.Click
        Dim idx As Integer, opDelete As Integer

        opDelete = MessageBox.Show("Are you sure you want to remove this profile?", "Confirm Profile Removal", MessageBoxButtons.YesNo, MessageBoxIcon.Question)

        ' Do we really want to delete it?
        If opDelete = MsgBoxResult.Yes Then
            ' Initialize XML profiles file
            XML = New XMLParser(Application.StartupPath, "profiles", "Profiles")

            ' Delete the selected profile (xml and array)
            XML.DeleteKey(Me.cbxProfiles.SelectedItem.ToString, Nothing)
            listProfiles.Remove(Me.cbxProfiles.SelectedItem.ToString)

            ' Refresh the profiles combobox and menus
            If Me.cbxProfiles.SelectedIndex = 0 Then : idx = 1
            Else : idx = Me.cbxProfiles.SelectedIndex - 1
            End If

            ' Refresh profiles if there are any left
            If Me.cbxProfiles.Items.Count > 1 Then
                RefreshProfiles(Me.cbxProfiles.Items.Item(idx).ToString)
            Else
                RefreshProfiles(Nothing)
            End If

            ' Disable some buttons if there are no profiles
            If listProfiles.Count = 0 Then
                Me.btnRemove.Enabled = False
                Me.btnEdit.Enabled = False
                Me.btnActivateProfile.Enabled = False
            End If
        End If
    End Sub

    ' Edit the current selected profile
    Private Sub btnEdit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnEdit.Click
        Dim frmEditProfile As New FormNewProfile

        ' Set edit profile variables
        editProfile = True
        profileName = Me.cbxProfiles.SelectedItem.ToString

        ' Change some controls according to "edit profile action"
        frmEditProfile.Text = "Edit Profile"
        frmEditProfile.lblCreatingProfile.Text = "Editing Profile:"
        frmEditProfile.lblProfileName.Location = New Point(frmEditProfile.lblProfileName.Location.X - 8, 370)

        ' Show new profile dialog
        frmEditProfile.ShowDialog()
    End Sub

    ' Activate some buttons if a profile was selected
    Private Sub cbxProfiles_SelectedValueChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles cbxProfiles.SelectedValueChanged
        If Not Me.btnActivateProfile.Enabled Then
            Me.btnRemove.Enabled = True
            Me.btnEdit.Enabled = True
            Me.btnActivateProfile.Enabled = True
        End If
    End Sub

    ' Display settings form or focus it
    Private Sub mnuSettings_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuSettings.Click
        If Not frmSettings.Visible Then
            frmSettings.ShowDialog()
        Else
            frmSettings.Focus()
        End If
    End Sub

    ' Display about form or focus it
    Private Sub mnuAbout_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuAbout.Click
        If Not frmAbout.Visible Then
            frmAbout.lblVersion.Text = "version " + realVersion
            frmAbout.ShowDialog()
        Else
            frmAbout.Focus()
        End If
    End Sub

    ' Compelety terminates the application
    Private Sub mnuExit_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuExit.Click
        Me.notifyIcon.Visible = False
        exitFromTray = True
        Application.Exit()
    End Sub

    ' Display the main form (manage profiles window)
    Private Sub mnuManageProfiles_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuManageProfiles.Click
        ShowHideForm()
    End Sub

    ' Handles the event for the notifymenu profile items
    Public Sub mnuItem_Click(ByVal sender As System.Object, ByVal e As System.EventArgs)
        ApplyProfile(sender.ToString)
    End Sub

    ' Launch default browser and open Network Switcher wiki
    Private Sub mnuHelp_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles mnuHelp.Click
        Process.Start("http://wiki.nazgulled.net/documentation:network_switcher")
    End Sub

    ' Display the main form (manage profiles window)
    Private Sub notifyIcon_MouseDoubleClick(ByVal sender As System.Object, ByVal e As System.Windows.Forms.MouseEventArgs) Handles notifyIcon.MouseDoubleClick
        ' Left mouse button?
        If e.Button = Windows.Forms.MouseButtons.Left Then
            Me.ShowHideForm()
        End If
    End Sub

    ' Applies the selected profile
    Private Sub btnActivateProfile_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnActivateProfile.Click
        ' Important settings not set?
        If Settings.NicFolder Is Nothing Or Settings.EnableVerb Is Nothing Or Settings.DisableVerb Is Nothing Then
            MessageBox.Show("No profile can be applied before configuring some important settings." + ControlChars.CrLf + "Settings dialog will now be displayed...", "Invalid Settings!", MessageBoxButtons.OK, MessageBoxIcon.Information)

            ' Focus the form if it's already visible or show the dialog
            If frmSettings.Visible Then
                frmSettings.Focus()
            Else
                frmSettings.ShowDialog()
            End If
        Else
            ApplyProfile(Me.cbxProfiles.SelectedItem.ToString)
        End If
    End Sub

    ' Displays about information for the selected plugin
    Private Sub lstAssignedPlugins_SelectedValueChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles lstAssignedPlugins.SelectedValueChanged
        Dim objPlugin As IPlugin = Nothing

        ' Get about information from the selected plugin
        If Not AvailablePlugins Is Nothing Then
            For I As Integer = 0 To AvailablePlugins.Length - 1
                objPlugin = DirectCast(PluginServices.CreateInstance(AvailablePlugins(I)), IPlugin)

                ' Is this the plugin being hovered?
                If objPlugin.PluginName = Me.lstAssignedPlugins.SelectedItem.ToString Then
                    Exit For
                End If
            Next
        End If

        ' Displays about information for this plugin
        Me.lblPluginAuthor.Text = objPlugin.PluginAuthor
        Me.lblPluginVersion.Text = objPlugin.PluginVersion
        Me.lblPluginDescription.Text = objPlugin.PluginDescription
    End Sub

    ' Paint the notifyicon context menu header
    Private Sub mnuHeader_Paint(ByVal sender As Object, ByVal e As System.Windows.Forms.PaintEventArgs) Handles mnuHeader.Paint
        ' Calculates sizes and starting/ending points for gradient and text
        Dim menuWidth As Integer = Me.notifyMenu.Width
        Dim StartP As Point = New Point(2, 0)
        Dim EndP As Point = New Point(menuWidth - 3, 0)
        Dim StartColor As Color = Color.FromArgb(255, 47, 57, 128)
        Dim EndColor As Color = Color.FromArgb(255, 25, 135, 202)
        Dim linearGradient As New Drawing2D.LinearGradientBrush(StartP, EndP, StartColor, EndColor)
        Dim mhFont As New Font("Tahoma", 8, FontStyle.Bold, GraphicsUnit.Point)

        ' Set correct size for header menu item
        Me.mnuHeader.Width = menuWidth - 1

        ' Designs a background gradient and foreground text
        e.Graphics.FillRectangle(linearGradient, 2, 0, menuWidth - 4, 15)
        e.Graphics.DrawString(Application.ProductName, mhFont, Brushes.White, 2, 0)
    End Sub

#End Region

#Region " Form Events "

    ' Hides the main form or closes the application
    Private Sub frmMain_FormClosing(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        ' The system is shuting down all applications?
        If Not e.CloseReason = CloseReason.WindowsShutDown Then
            ' Are we just closing the form?
            If Not exitFromTray Then
                ' Exit application on form closing or hide it?
                If Settings.ExitOnClosing Then
                    Me.notifyIcon.Visible = False
                    Application.Exit()
                Else
                    e.Cancel = True
                    ShowHideForm()
                End If
            End If
        End If
    End Sub

#End Region

#Region " Private Methods "

    ' Method: Show/hide the main form enabling/disabling the menu show item
    Private Sub ShowHideForm()
        If Not Me.Visible Then
            ' Important settings not set?
            If Settings.NicFolder Is Nothing Or Settings.EnableVerb Is Nothing Or Settings.DisableVerb Is Nothing Then
                MessageBox.Show("Before start using Network Switcher, you must configure some important settings." + ControlChars.CrLf + "Settings dialog will now be displayed...", "Invalid Settings!", MessageBoxButtons.OK, MessageBoxIcon.Information)

                ' Focus the form if it's already visible or show the dialog
                If frmSettings.Visible Then
                    frmSettings.Focus()
                Else
                    Dim dlgResult As DialogResult = frmSettings.ShowDialog()

                    ' Important settings correctly set?
                    If dlgResult = Windows.Forms.DialogResult.OK Then
                        Me.Show()
                        Me.mnuManageProfiles.Enabled = False
                    End If
                End If
            Else
                Me.Show()
                Me.mnuManageProfiles.Enabled = False
            End If
        Else
            Me.Hide()
            Me.mnuManageProfiles.Enabled = True
        End If
    End Sub

#End Region

End Class